==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/components/popover/PopoverBase.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/components/popover/PopoverBase.es", ['module', 'exports', 'require', 'frontend-js-react-web$classnames', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../utils/omitDefinedProps.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.PopoverBase = void 0;

  var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

  var _propTypes = require("frontend-js-react-web$prop-types");

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  var _omitDefinedProps = _interopRequireDefault(require("../../utils/omitDefinedProps.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }return target;
    };return _extends.apply(this, arguments);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  var Header = function Header(_ref) {
    var children = _ref.children;
    return _react["default"].createElement("div", {
      className: "border-0 popover-header"
    }, children);
  };

  var Body = function Body(_ref2) {
    var children = _ref2.children;
    return _react["default"].createElement("div", {
      className: "popover-body"
    }, children);
  };

  var Footer = function Footer(_ref3) {
    var children = _ref3.children;
    return _react["default"].createElement("div", {
      className: "popover-footer"
    }, children);
  };

  var PopoverBase = function PopoverBase(_ref4) {
    var _classNames;

    var children = _ref4.children,
        className = _ref4.className,
        forwardRef = _ref4.forwardRef,
        _ref4$placement = _ref4.placement,
        placement = _ref4$placement === void 0 ? 'none' : _ref4$placement,
        _ref4$visible = _ref4.visible,
        visible = _ref4$visible === void 0 ? false : _ref4$visible,
        otherProps = _objectWithoutProperties(_ref4, ["children", "className", "forwardRef", "placement", "visible"]);

    return _react["default"].createElement("div", _extends({}, (0, _omitDefinedProps["default"])(otherProps, PopoverBase.propTypes), {
      className: (0, _classnames["default"])('popover', className, (_classNames = {}, _defineProperty(_classNames, "clay-popover-".concat(placement), placement), _defineProperty(_classNames, "hide", !visible), _classNames)),
      ref: forwardRef
    }), placement !== 'none' && _react["default"].createElement("div", {
      className: "arrow"
    }), children);
  };

  exports.PopoverBase = PopoverBase;
  PopoverBase.propTypes = {
    placement: _propTypes.PropTypes.oneOf(['bottom', 'left', 'none', 'right', 'top']),
    visible: _propTypes.PropTypes.bool
  };
  PopoverBase.Header = Header;
  PopoverBase.Body = Body;
  PopoverBase.Footer = Footer;
  var _default = PopoverBase;
  exports["default"] = _default;
  //# sourceMappingURL=PopoverBase.es.js.map
});
//# sourceMappingURL=PopoverBase.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/components/popover/PopoverBase.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/components/popover/PopoverBase.es", ['module', 'exports', 'require', 'frontend-js-react-web$classnames', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.PopoverBase = void 0;

  var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

  var _propTypes = require("frontend-js-react-web$prop-types");

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }return target;
    };return _extends.apply(this, arguments);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  var Header = function Header(_ref) {
    var children = _ref.children;
    return _react["default"].createElement("div", {
      className: "border-0 popover-header"
    }, children);
  };

  var Body = function Body(_ref2) {
    var children = _ref2.children;
    return _react["default"].createElement("div", {
      className: "popover-body"
    }, children);
  };

  var Footer = function Footer(_ref3) {
    var children = _ref3.children;
    return _react["default"].createElement("div", {
      className: "popover-footer"
    }, children);
  };

  var PopoverBase = function PopoverBase(_ref4) {
    var _classNames;

    var children = _ref4.children,
        className = _ref4.className,
        forwardRef = _ref4.forwardRef,
        _ref4$placement = _ref4.placement,
        placement = _ref4$placement === void 0 ? 'none' : _ref4$placement,
        _ref4$visible = _ref4.visible,
        visible = _ref4$visible === void 0 ? false : _ref4$visible,
        otherProps = _objectWithoutProperties(_ref4, ["children", "className", "forwardRef", "placement", "visible"]);

    return _react["default"].createElement("div", _extends({}, otherProps, {
      className: (0, _classnames["default"])('popover', className, (_classNames = {}, _defineProperty(_classNames, "clay-popover-".concat(placement), placement), _defineProperty(_classNames, "hide", !visible), _classNames)),
      ref: forwardRef
    }), placement !== 'none' && _react["default"].createElement("div", {
      className: "arrow"
    }), children);
  };

  exports.PopoverBase = PopoverBase;
  PopoverBase.Header = Header;
  PopoverBase.Body = Body;
  PopoverBase.Footer = Footer;
  var _default = PopoverBase;
  exports["default"] = _default;
  //# sourceMappingURL=PopoverBase.es.js.map
});
//# sourceMappingURL=PopoverBase.es.js.map
